@@ -41,8 +41,9 @@ class DesktopCommand(Command):
         self.run_app()
 
     def prepare_run(self):
-        if not (self.config.desktop_skip_build
-                or self.custom_mode):
+        if self.config.desktop_skip_build or self.custom_mode:
+            self.config.container.setup()
+        else:
             if not self.config.dirty:
                 CleanCommand(self.config).run()
             BuildCommand(self.config).run()
@@ -129,7 +130,7 @@ class DesktopCommand(Command):
 
     def get_time_zone(self):
         try:
-            return run_subprocess_check_output('timedatectl show -p Timezone --value')
+            return run_subprocess_check_output('timedatectl show -p Timezone --value 2>/dev/null')
         except:
             pass
 
@@ -146,6 +147,7 @@ class DesktopCommand(Command):
                     end = line.find('(')
                     return line[start:end].strip()
         except:
+            logger.debug("Failed to set timezone from host in desktop mode. Falling back to UTC.")
             pass
 
         return 'UTC'
